==> _private_core_network-1.2.25.tar.gz: lib/network_resources/model/payment_request.dart <==
class PaymentRequestModel {
  int? purchaseType;
  String? proUniqueId;
  double? amount;
  String? currency;
  int? commissionId;
  int? deliveryLocationId;
  String? qrCode;
  int? fromShop;
  String? orderId;
  String? shopUniqueId;
  String? ticketUniqueId;
  List<PaymentRequestProductRefs>? productRefs;
  String? tokenType;
  double? priceByUnit;
  String? countryCode;
  int? cardId;
  int? platformId;
  String? label;

  PaymentRequestModel({
    this.purchaseType,
    this.proUniqueId,
    this.amount,
    this.currency,
    this.commissionId,
    this.deliveryLocationId,
    this.qrCode,
    this.fromShop,
    this.orderId,
    this.shopUniqueId,
    this.ticketUniqueId,
    this.productRefs,
    this.tokenType,
    this.priceByUnit,
    this.countryCode,
    this.cardId,
    this.platformId,
    this.label,
  });

  PaymentRequestModel.fromJson(Map<String, dynamic> json) {
    purchaseType = json["purchaseType"];
    proUniqueId = json["proUniqueId"];
    amount = json["amount"];
    currency = json["currency"];
    commissionId = json["commissionId"];
    deliveryLocationId = json["deliveryLocationId"];
    qrCode = json["qrCode"];
    fromShop = json["fromShop"];
    orderId = json["orderId"];
    shopUniqueId = json["shopUniqueId"];
    ticketUniqueId = json["ticketUniqueId"];
    productRefs = json["productRefs"] == null
        ? null
        : (json["productRefs"] as List)
            .map((e) => PaymentRequestProductRefs.fromJson(e))
            .toList();
    tokenType = json["tokenType"];
    priceByUnit = json["priceByUnit"];
    countryCode = json["countryCode"];
    cardId = json["cardId"];
    platformId = json["platformId"];
    label = json["label"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["purchaseType"] = purchaseType;
    _data["proUniqueId"] = proUniqueId;
    _data["amount"] = amount;
    _data["currency"] = currency;
    _data["commissionId"] = commissionId;
    _data["deliveryLocationId"] = deliveryLocationId;
    _data["qrCode"] = qrCode;
    _data["fromShop"] = fromShop;
    _data["orderId"] = orderId;
    _data["shopUniqueId"] = shopUniqueId;
    _data["ticketUniqueId"] = ticketUniqueId;
    if (productRefs != null) {
      _data["productRefs"] = productRefs?.map((e) => e.toJson()).toList();
    }
    _data["tokenType"] = tokenType;
    _data["priceByUnit"] = priceByUnit;
    _data["countryCode"] = countryCode;
    _data["cardId"] = cardId;
    _data["platformId"] = platformId;
    _data["label"] = label;
    return _data;
  }
}

class PaymentRequestProductRefs {
  int? id;
  int? quantity;
  String? type;

  PaymentRequestProductRefs({this.id, this.quantity, this.type});

  PaymentRequestProductRefs.fromJson(Map<String, dynamic> json) {
    id = json["id"];
    quantity = json["quantity"];
    type = json["type"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> _data = <String, dynamic>{};
    _data["id"] = id;
    _data["quantity"] = quantity;
    _data["type"] = type;
    return _data;
  }
}

==> _private_core_network-1.3.48.tar.gz: lib/network_resources/model/payment_request.dart <==
class PaymentRequestModel {
  int? purchaseType;
  String? proUniqueId;
  double? amount;
  String? currency;
  int? commissionId;
  int? deliveryLocationId;
  String? qrCode;
  int? fromShop;
  String? orderId;
  String? shopUniqueId;
  String? ticketUniqueId;
  List<PaymentRequestProductRefs>? productRefs;
  String? tokenType;
  double? priceByUnit;
  String? countryCode;
  int? cardId;
  int? platformId;
  String? label;

  PaymentRequestModel({
    this.purchaseType,
    this.proUniqueId,
    this.amount,
    this.currency,
    this.commissionId,
    this.deliveryLocationId,
    this.qrCode,
    this.fromShop,
    this.orderId,
    this.shopUniqueId,
    this.ticketUniqueId,
    this.productRefs,
    this.tokenType,
    this.priceByUnit,
    this.countryCode,
    this.cardId,
    this.platformId,
    this.label,
  });

  PaymentRequestModel.fromJson(Map<String, dynamic> json) {
    purchaseType = json["purchaseType"];
    proUniqueId = json["proUniqueId"];
    amount = json["amount"];
    currency = json["currency"];
    commissionId = json["commissionId"];
    deliveryLocationId = json["deliveryLocationId"];
    qrCode = json["qrCode"];
    fromShop = json["fromShop"];
    orderId = json["orderId"];
    shopUniqueId = json["shopUniqueId"];
    ticketUniqueId = json["ticketUniqueId"];
    productRefs = json["productRefs"] == null
        ? null
        : (json["productRefs"] as List)
            .map((e) => PaymentRequestProductRefs.fromJson(e))
            .toList();
    tokenType = json["tokenType"];
    priceByUnit = json["priceByUnit"];
    countryCode = json["countryCode"];
    cardId = json["cardId"];
    platformId = json["platformId"];
    label = json["label"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data["purchaseType"] = purchaseType;
    data["proUniqueId"] = proUniqueId;
    data["amount"] = amount;
    data["currency"] = currency;
    data["commissionId"] = commissionId;
    data["deliveryLocationId"] = deliveryLocationId;
    data["qrCode"] = qrCode;
    data["fromShop"] = fromShop;
    data["orderId"] = orderId;
    data["shopUniqueId"] = shopUniqueId;
    data["ticketUniqueId"] = ticketUniqueId;
    if (productRefs != null) {
      data["productRefs"] = productRefs?.map((e) => e.toJson()).toList();
    }
    data["tokenType"] = tokenType;
    data["priceByUnit"] = priceByUnit;
    data["countryCode"] = countryCode;
    data["cardId"] = cardId;
    data["platformId"] = platformId;
    data["label"] = label;
    return data;
  }
}

class PaymentRequestProductRefs {
  int? id;
  int? quantity;
  String? type;

  PaymentRequestProductRefs({this.id, this.quantity, this.type});

  PaymentRequestProductRefs.fromJson(Map<String, dynamic> json) {
    id = json["id"];
    quantity = json["quantity"];
    type = json["type"];
  }

  Map<String, dynamic> toJson() {
    final Map<String, dynamic> data = <String, dynamic>{};
    data["id"] = id;
    data["quantity"] = quantity;
    data["type"] = type;
    return data;
  }
}
